summaryrefslogtreecommitdiffstats
path: root/tdeui/kpanelapplet.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:13 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:13 -0600
commit56160bf4dfe503631ef6373367b281f081bab2b4 (patch)
tree7fcea2ffd9c3420af999c3dcad0ed032eef93956 /tdeui/kpanelapplet.h
parent13281e2856a2ef43bbab78c5528470309c23aa77 (diff)
downloadtdelibs-56160bf4dfe503631ef6373367b281f081bab2b4.tar.gz
tdelibs-56160bf4dfe503631ef6373367b281f081bab2b4.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 13281e2856a2ef43bbab78c5528470309c23aa77.
Diffstat (limited to 'tdeui/kpanelapplet.h')
-rw-r--r--tdeui/kpanelapplet.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/tdeui/kpanelapplet.h b/tdeui/kpanelapplet.h
index 0d3ac430f..a51f16fda 100644
--- a/tdeui/kpanelapplet.h
+++ b/tdeui/kpanelapplet.h
@@ -308,9 +308,9 @@ protected:
**/
Position position() const { return _position; }
/**
* @return the applet's alignment. (top/left, center, or bottom/right)
**/
- Alignment alignment() const { return _alignment; }
+ Alignment tqalignment() const { return _tqalignment; }
/**
* The panel on which this applet resides has changed its position.
@@ -320,7 +320,7 @@ protected:
virtual void positionChange( Position p );
/**
* The panel on which this applet resides has changed its alignment.
* Reimplement this change handler in order to adjust the look of your
* applet.
**/
@@ -383,7 +383,7 @@ protected:
private:
Type _type;
Position _position;
- Alignment _alignment;
+ Alignment _tqalignment;
KConfig* _config;
int _actions;
protected:
@@ -308,9 +308,9 @@ protected:
Position position() const { return _position; }
/**
- * @return the applet's alignment. (top/left, center, or bottom/right)
+ * @return the applet's tqalignment. (top/left, center, or bottom/right)
**/
@@ -320,7 +320,7 @@ protected:
virtual void positionChange( Position p );
/**
- * The panel on which this applet resides has changed its alignment.
+ * The panel on which this applet resides has changed its tqalignment.
* Reimplement this change handler in order to adjust the look of your
* applet.